import { RpsContext } from 'rpscript-interface';
import { TemplateExecutor } from 'lodash';
/** Module for Lodash
 * @namespace Lodash
 *
 * @see {@link https://lodash.com/docs}
*/
export default class RpsLodash {
    /**
   * @function chunk
   * @memberof Lodash
   *
   * @param {Array} array
   * @param {number} size
   * @returns {Array}
   *
   * @see {@link https://lodash.com/docs#chunk}
  */
    chunk(ctx: RpsContext, opts: {}, array: any[], size?: number): Promise<any[]>;
    /**
   * @function compact
   * @memberof Lodash
   *
   * @param {Array} array
   * @returns {Array}
   *
   * @see {@link https://lodash.com/docs#compact}
  */
    compact(ctx: RpsContext, opts: {}, array: any[]): Promise<any[]>;
    /**
     * @function concat
     * @memberof Lodash
     *
     * @param {Array} array
     * @returns {List} values
     *
     * @see {@link https://lodash.com/docs#concat}
    */
    concat(ctx: RpsContext, opts: {}, array: any[], ...values: any[]): Promise<any[]>;
    /**
     * @function difference
     * @memberof Lodash
     *
     * @param {Array} array
     * @returns {Array} values
     *
     * @see {@link https://lodash.com/docs#difference}
    */
    difference(ctx: RpsContext, opts: {}, array: any[], values: any[]): Promise<any[]>;
    /**
   * @function drop
   * @memberof Lodash
   *
   * @param {Array} array
   * @returns {number} size
   *
   * @see {@link https://lodash.com/docs#drop}
  */
    drop(ctx: RpsContext, opts: {}, array: any[], size?: number): Promise<any[]>;
    /**
   * @function drop-right
   * @memberof Lodash
   *
   * @param {Array} array
   * @returns {number} size
   *
   * @see {@link https://lodash.com/docs#dropRight}
  */
    dropRight(ctx: RpsContext, opts: {}, array: any[], size?: number): Promise<any[]>;
    /**
   * @function fill
   * @memberof Lodash
   *
   * @param {Array} array
   * @returns {Array} values
   *
   * @see {@link https://lodash.com/docs#fill}
  */
    fill(ctx: RpsContext, opts: {}, array: any[], value: any): Promise<any[]>;
    /**
     * @function find-index
     * @memberof Lodash
     *
     * @param {Array} array
     * @returns {Array} values
     *
     * @see {@link https://lodash.com/docs#findIndex}
    */
    findIndex(ctx: RpsContext, opts: {}, array: any[], predicate: any, fromIndex?: number): Promise<number>;
    /**
     * @function find-last-index
     * @memberof Lodash
     *
     * @param {Array} array
     * @returns {Array} values
     *
     * @see {@link https://lodash.com/docs#findLastIndex}
    */
    findLastIndex(ctx: RpsContext, opts: {}, array: any[], predicate: any, fromIndex?: number): Promise<number>;
    /**
     * @function flatten
     * @memberof Lodash
     *
     * @param {Array} array
     * @returns {Array}
     *
     * @see {@link https://lodash.com/docs#flatten}
    */
    flatten(ctx: RpsContext, opts: {}, array: any[]): Promise<any[]>;
    /**
     * @function flatten-deep
     * @memberof Lodash
     *
     * @param {Array} array
     * @returns {Array}
     *
     * @see {@link https://lodash.com/docs#flattenDeep}
    */
    flattenDeep(ctx: RpsContext, opts: {}, array: any[]): Promise<any[]>;
    /**
     * @function from-pairs
     * @memberof Lodash
     *
     * @param {Array} pairs
     * @returns {Object}
     *
     * @see {@link https://lodash.com/docs#fromPairs}
    */
    fromPairs(ctx: RpsContext, opts: {}, pairs: any[]): Promise<Object>;
    /**
     * @function head
     * @memberof Lodash
     *
     * @param {Array}
     * @returns {Object}
     *
     * @see {@link https://lodash.com/docs#head}
    */
    head(ctx: RpsContext, opts: {}, array: any[]): Promise<any>;
    /**
     * @function index-of
     * @memberof Lodash
     *
     * @param {Array} array
     * @param {*} value
     * @param {number} fromIndex optional.
     * @returns {number}
     *
     * @see {@link https://lodash.com/docs#indexOf}
    */
    indexOf(ctx: RpsContext, opts: {}, array: any[], value: any, fromIndex?: number): Promise<number>;
    /**
   * @function initial
   * @memberof Lodash
   *
   * @param {Array} array
   * @returns {Array}
   *
   * @see {@link https://lodash.com/docs#initial}
  */
    initial(ctx: RpsContext, opts: {}, array: any[]): Promise<any[]>;
    /**
     * @function intersection
     * @memberof Lodash
     *
     * @param {Array} arrays
     * @returns {Array}
     *
     * @see {@link https://lodash.com/docs#intersection}
    */
    intersection(ctx: RpsContext, opts: {}, arrays: any[]): Promise<any[]>;
    /**
     * @function join
     * @memberof Lodash
     *
     * @param {Array} array
     * @param {Array} separator
     * @returns {string}
     *
     * @see {@link https://lodash.com/docs#intersection}
    */
    join(ctx: RpsContext, opts: {}, array: any[], separator?: string): Promise<string>;
    /**
     * @function last
     * @memberof Lodash
     *
     * @param {Array} array
     * @returns {Array}
     *
     * @see {@link https://lodash.com/docs#last}
    */
    last(ctx: RpsContext, opts: {}, array: any[]): Promise<any>;
    /**
     * @function last-index-of
     * @memberof Lodash
     *
     * @param {Array} array
     * @param {*} value
     * @param {number} fromIndex
     * @returns {Array}
     *
     * @see {@link https://lodash.com/docs#lastIndexOf}
    */
    lastIndexOf(ctx: RpsContext, opts: {}, array: any[], value: any, fromIndex?: number): Promise<any>;
    /**
     * @function nth
     * @memberof Lodash
     *
     * @param {Array} array
     * @param {*} n
     * @returns {Array}
     *
     * @see {@link https://lodash.com/docs#nth}
    */
    nth(ctx: RpsContext, opts: {}, array: any[], n?: number): Promise<any>;
    /**
     * @function pull
     * @memberof Lodash
     *
     * @param {Array} array
     * @param {*} values
     * @returns {Array}
     *
     * @see {@link https://lodash.com/docs#pull}
    */
    pull(ctx: RpsContext, opts: {}, array: any[], ...values: any[]): Promise<any>;
    /**
     * @function pull-all
     * @memberof Lodash
     *
     * @param {Array} array
     * @param {*} values
     * @returns {Array}
     *
     * @see {@link https://lodash.com/docs#pullAll}
    */
    pullAll(ctx: RpsContext, opts: {}, array: any[], values: any[]): Promise<any>;
    /**
     * @function pull-all-by
     * @memberof Lodash
     *
     * @param {Array} array
     * @param {*} values
     * @param {*} function
     * @returns {Array}
     *
     * @see {@link https://lodash.com/docs#pullAllBy}
    */
    pullAllBy(ctx: RpsContext, opts: {}, array: any[], values: any[], fn: any): Promise<any>;
    /**
     * @function remove
     * @memberof Lodash
     *
     * @param {Array} array
     * @param {*} predicate
     * @returns {Array}
     *
     * @see {@link https://lodash.com/docs#remove}
    */
    remove(ctx: RpsContext, opts: {}, array: any[], predicate: any): Promise<any[]>;
    /**
     * @function reverse
     * @memberof Lodash
     *
     * @param {Array} array
     * @returns {Array}
     *
     * @see {@link https://lodash.com/docs#reverse}
    */
    reverse(ctx: RpsContext, opts: {}, array: any[]): Promise<any[]>;
    /**
     * @function slice
     * @memberof Lodash
     *
     * @param {Array} array
     * @returns {Array}
     *
     * @see {@link https://lodash.com/docs#slice}
    */
    slice(ctx: RpsContext, opts: {}, array: any[], start?: number, end?: number): Promise<any[]>;
    /**
     * @function sorted-index
     * @memberof Lodash
     *
     * @param {Array} array
     * @returns {Array}
     *
     * @see {@link https://lodash.com/docs#sortedIndex}
    */
    sortedIndex(ctx: RpsContext, opts: {}, array: any[], value: number): Promise<number>;
    /**
     * @function sorted-uniq
     * @memberof Lodash
     *
     * @param {Array} array
     * @returns {Array}
     *
     * @see {@link https://lodash.com/docs#sortedUniq}
    */
    sortedUniq(ctx: RpsContext, opts: {}, array: any[]): Promise<any[]>;
    /**
     * @function tail
     * @memberof Lodash
     *
     * @param {Array} array
     * @returns {Array}
     *
     * @see {@link https://lodash.com/docs#tail}
    */
    tail(ctx: RpsContext, opts: {}, array: any[]): Promise<any>;
    /**
     * @function take
     * @memberof Lodash
     *
     * @param {Array} array
     * @param {number} n
     * @returns {Array}
     *
     * @see {@link https://lodash.com/docs#take}
    */
    take(ctx: RpsContext, opts: {}, array: any[], n?: number): Promise<any>;
    /**
     * @function take-right
     * @memberof Lodash
     *
     * @param {Array} array
     * @param {number} n
     * @returns {Array}
     *
     * @see {@link https://lodash.com/docs#takeRight}
    */
    takeRight(ctx: RpsContext, opts: {}, array: any[], n?: number): Promise<any>;
    /**
     * @function union
     * @memberof Lodash
     *
     * @param {Array} arrays
     * @returns {Array}
     *
     * @see {@link https://lodash.com/docs#union}
    */
    union(ctx: RpsContext, opts: {}, ...arrays: any[]): Promise<any[]>;
    /**
     * @function uniq
     * @memberof Lodash
     *
     * @param {Array} array
     * @returns {Array}
     *
     * @see {@link https://lodash.com/docs#uniq}
    */
    uniq(ctx: RpsContext, opts: {}, array: any[]): Promise<any[]>;
    /**
     * @function unzip
     * @memberof Lodash
     *
     * @param {Array} array
     * @returns {Array}
     *
     * @see {@link https://lodash.com/docs#unzip}
    */
    unzip(ctx: RpsContext, opts: {}, ...array: any[]): Promise<any[]>;
    /**
     * @function without
     * @memberof Lodash
     *
     * @param {Array} array
     * @param {List} values
     * @returns {Array}
     *
     * @see {@link https://lodash.com/docs#without}
    */
    without(ctx: RpsContext, opts: {}, array: any[], ...values: any[]): Promise<any[]>;
    /**
     * @function xor
     * @memberof Lodash
     *
     * @param {Array} arrays
     * @returns {Array}
     *
     * @see {@link https://lodash.com/docs#xor}
    */
    xor(ctx: RpsContext, opts: {}, ...array: any[]): Promise<any[]>;
    /**
     * @function zip
     * @memberof Lodash
     *
     * @param {Array} array
     * @returns {Array}
     *
     * @see {@link https://lodash.com/docs#zip}
    */
    zip(ctx: RpsContext, opts: {}, ...array: any[]): Promise<any[]>;
    /**
     * @function zip-object
     * @memberof Lodash
     *
     * @param {Array} properties
     * @param {Array} values
     * @returns {Array}
     *
     * @see {@link https://lodash.com/docs#zipObject}
    */
    zipObject(ctx: RpsContext, opts: {}, properties: any[], values: any[]): Promise<Object>;
    /**
     * @function zip-object-deep
     * @memberof Lodash
     *
     * @param {Array} properties
     * @param {Array} values
     * @returns {Array}
     *
     * @see {@link https://lodash.com/docs#zipObjectDeep}
    */
    zipObjectDeep(ctx: RpsContext, opts: {}, properties: any[], values: any[]): Promise<Object>;
    /**
     * @function zip-with
     * @memberof Lodash
     *
     * @param {Array} properties
     * @param {Array} values
     * @returns {Array}
     *
     * @see {@link https://lodash.com/docs#zipWith}
    */
    zipWith(ctx: RpsContext, opts: {}, identity: Function, ...arrays: any[]): Promise<any[]>;
    map(ctx: RpsContext, opts: {}, functor: any[], fn: Function): Promise<any[]>;
    filter(ctx: RpsContext, opts: {}, functor: any[], fn: any): Promise<any[]>;
    find(ctx: RpsContext, opts: {}, functor: any[], fn: any): Promise<any>;
    keys(ctx: RpsContext, opts: {}, functor: Object, fn: any): Promise<any[]>;
    values(ctx: RpsContext, opts: {}, functor: Object, fn: any): Promise<any[]>;
    pick(ctx: RpsContext, opts: {}, functor: Object, fn: any): Promise<Object>;
    forEach(ctx: RpsContext, opts: {}, functor: any[], fn: Function): Promise<void>;
    now(ctx: RpsContext, opts: {}): Promise<Date>;
    camelCase(ctx: RpsContext, opts: {}, text: string): Promise<string>;
    capitalize(ctx: RpsContext, opts: {}, text: string): Promise<string>;
    deburr(ctx: RpsContext, opts: {}, text: string): Promise<string>;
    endsWith(ctx: RpsContext, opts: Object, target: string, text: string): Promise<boolean>;
    escape(ctx: RpsContext, opts: {}, text: string): Promise<string>;
    escapeRegExp(ctx: RpsContext, opts: {}, text: string): Promise<string>;
    kebabCase(ctx: RpsContext, opts: {}, text: string): Promise<string>;
    lowerCase(ctx: RpsContext, opts: {}, text: string): Promise<string>;
    lowerFirst(ctx: RpsContext, opts: {}, text: string): Promise<string>;
    pad(ctx: RpsContext, opts: Object, length: number, text: string): Promise<string>;
    padEnd(ctx: RpsContext, opts: Object, length: number, text: string): Promise<string>;
    padStart(ctx: RpsContext, opts: Object, length: number, text: string): Promise<string>;
    parseInt(ctx: RpsContext, opts: Object, text: string): Promise<number>;
    repeat(ctx: RpsContext, opts: {}, n: number, text: string): Promise<string>;
    replace(ctx: RpsContext, opts: {}, pattern: string | RegExp, replacement: string, text: string): Promise<string>;
    snakeCase(ctx: RpsContext, opts: {}, text: string): Promise<string>;
    split(ctx: RpsContext, opts: {}, separator: string | RegExp, text: string): Promise<string[]>;
    startCase(ctx: RpsContext, opts: {}, text: string): Promise<string>;
    startsWith(ctx: RpsContext, opts: Object, target: string, text: string): Promise<boolean>;
    template(ctx: RpsContext, opts: Object, text: string): Promise<TemplateExecutor>;
    toLower(ctx: RpsContext, opts: Object, text: string): Promise<string>;
    toUpper(ctx: RpsContext, opts: Object, text: string): Promise<string>;
    trim(ctx: RpsContext, opts: Object, text: string): Promise<string>;
    trimEnd(ctx: RpsContext, opts: Object, text: string): Promise<string>;
    trimStart(ctx: RpsContext, opts: Object, text: string): Promise<string>;
    truncate(ctx: RpsContext, opts: Object, text: string): Promise<string>;
    unescape(ctx: RpsContext, opts: Object, text: string): Promise<string>;
    upperCase(ctx: RpsContext, opts: {}, text: string): Promise<string>;
    upperFirst(ctx: RpsContext, opts: {}, text: string): Promise<string>;
    words(ctx: RpsContext, opts: {}, pattern: string, text: string): Promise<string[]>;
    regex(ctx: RpsContext, opts: {}, pattern: string, flags?: string): Promise<RegExp>;
    getLodashFunction(ctx: RpsContext, opts: {}, fnName: string, ...params: any[]): Promise<any>;
}
